pub enum TypeExpr {
}Expand description
A type expression used by declarations, fields, parameters, and returns.
TypeExpr::Named references are resolved only within the containing
descriptor. Recursive references, including recursion through lists,
records, and unions, are invalid.
Variants
Unit
A value carrying no data.
Boolean
A boolean.
Integer
A JavaScript-lossless signed integer.
Number
A finite IEEE-754 binary64 number.
String
A Unicode string.
Bytes
An opaque byte sequence.
Json
A schema-opaque JSON-compatible value tree.
Entry
A canonical absolute Worldspace path represented by a string value.
Named
A descriptor-local named declaration.
Record
A record with named fields.
Fields

fields: Vec<FieldDeclaration>Fields in declaration order.
List
An ordered list.
Enum
A closed set of payload-free cases represented by strings.
Union
A discriminated union represented by a record.